@@ -2,6 +2,6 @@ postvar <-
   function(Kmat,Jmat,Cisqrt){
   ### get posterior variance
   
-  pvar=rowSums((cbind(Kmat,Jmat)%*%Cisqrt)^2)
+  pvar <- rowSums((cbind(Kmat,Jmat)%*%Cisqrt)^2)
   
 }
