@@ -1,5 +1,5 @@
 unifqsumg <-
   function(x){
-    x=matrix(x,ncol=2)
+    x <- matrix(x,ncol=2)
     c(x[1,1],sum(x[,2]),length(x[,1]),crossprod(x[,2]))
   }
